# rubelp
Rule-based engine for linguistic processing. 

![build-badge](https://img.shields.io/github/actions/workflow/status/Jerem-dY/rubelp/CI.yml)
[![doc-badge](https://readthedocs.org/projects/rubelp/badge/?version=latest)](https://rubelp.readthedocs.io/en/latest/?badge=latest)
![GitHub](https://img.shields.io/github/license/Jerem-dY/rubelp)
![GitHub release (latest by date)](https://img.shields.io/github/v/release/Jerem-dY/rubelp?logo=github)
![PyPI](https://img.shields.io/pypi/v/rubelp)
![Twitter URL](https://img.shields.io/twitter/url?style=social&url=https%3A%2F%2Ftwitter.com%2FJB09SI)

La documentation python du projet se trouve ici : https://rubelp.readthedocs.io/en/latest/